==> zio-aws-macie2_2.12-5.17.126.2-sources.jar: zio/aws/macie2/model/UserIdentityRoot.scala <==
package zio.aws.macie2.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.macie2.model.primitives.__string
import scala.jdk.CollectionConverters._
final case class UserIdentityRoot(
    accountId: Option[__string] = None,
    arn: Option[__string] = None,
    principalId: Option[__string] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.macie2.model.UserIdentityRoot = {
    import UserIdentityRoot.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.macie2.model.UserIdentityRoot
      .builder()
      .optionallyWith(
        accountId.map(value => __string.unwrap(value): java.lang.String)
      )(_.accountId)
      .optionallyWith(
        arn.map(value => __string.unwrap(value): java.lang.String)
      )(_.arn)
      .optionallyWith(
        principalId.map(value => __string.unwrap(value): java.lang.String)
      )(_.principalId)
      .build()
  }
  def asReadOnly: zio.aws.macie2.model.UserIdentityRoot.ReadOnly =
    zio.aws.macie2.model.UserIdentityRoot.wrap(buildAwsValue())
}
object UserIdentityRoot {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.macie2.model.UserIdentityRoot
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.macie2.model.UserIdentityRoot =
      zio.aws.macie2.model.UserIdentityRoot(
        accountId.map(value => value),
        arn.map(value => value),
        principalId.map(value => value)
      )
    def accountId: Option[__string]
    def arn: Option[__string]
    def principalId: Option[__string]
    def getAccountId: ZIO[Any, AwsError, __string] =
      AwsError.unwrapOptionField("accountId", accountId)
    def getArn: ZIO[Any, AwsError, __string] =
      AwsError.unwrapOptionField("arn", arn)
    def getPrincipalId: ZIO[Any, AwsError, __string] =
      AwsError.unwrapOptionField("principalId", principalId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.macie2.model.UserIdentityRoot
  ) extends zio.aws.macie2.model.UserIdentityRoot.ReadOnly {
    override val accountId: Option[__string] = scala
      .Option(impl.accountId())
      .map(value => zio.aws.macie2.model.primitives.__string(value))
    override val arn: Option[__string] = scala
      .Option(impl.arn())
      .map(value => zio.aws.macie2.model.primitives.__string(value))
    override val principalId: Option[__string] = scala
      .Option(impl.principalId())
      .map(value => zio.aws.macie2.model.primitives.__string(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.macie2.model.UserIdentityRoot
  ): zio.aws.macie2.model.UserIdentityRoot.ReadOnly = new Wrapper(impl)
}

==> zio-aws-macie2_2.12-5.17.149.1-sources.jar: zio/aws/macie2/model/UserIdentityRoot.scala <==
package zio.aws.macie2.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.macie2.model.primitives.__string
import scala.jdk.CollectionConverters._
final case class UserIdentityRoot(
    accountId: Option[__string] = None,
    arn: Option[__string] = None,
    principalId: Option[__string] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.macie2.model.UserIdentityRoot = {
    import UserIdentityRoot.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.macie2.model.UserIdentityRoot
      .builder()
      .optionallyWith(accountId.map(value => value: java.lang.String))(
        _.accountId
      )
      .optionallyWith(arn.map(value => value: java.lang.String))(_.arn)
      .optionallyWith(principalId.map(value => value: java.lang.String))(
        _.principalId
      )
      .build()
  }
  def asReadOnly: zio.aws.macie2.model.UserIdentityRoot.ReadOnly =
    zio.aws.macie2.model.UserIdentityRoot.wrap(buildAwsValue())
}
object UserIdentityRoot {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.macie2.model.UserIdentityRoot
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.macie2.model.UserIdentityRoot =
      zio.aws.macie2.model.UserIdentityRoot(
        accountId.map(value => value),
        arn.map(value => value),
        principalId.map(value => value)
      )
    def accountId: Option[__string]
    def arn: Option[__string]
    def principalId: Option[__string]
    def getAccountId: ZIO[Any, AwsError, __string] =
      AwsError.unwrapOptionField("accountId", accountId)
    def getArn: ZIO[Any, AwsError, __string] =
      AwsError.unwrapOptionField("arn", arn)
    def getPrincipalId: ZIO[Any, AwsError, __string] =
      AwsError.unwrapOptionField("principalId", principalId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.macie2.model.UserIdentityRoot
  ) extends zio.aws.macie2.model.UserIdentityRoot.ReadOnly {
    override val accountId: Option[__string] =
      scala.Option(impl.accountId()).map(value => value: __string)
    override val arn: Option[__string] =
      scala.Option(impl.arn()).map(value => value: __string)
    override val principalId: Option[__string] =
      scala.Option(impl.principalId()).map(value => value: __string)
  }
  def wrap(
      impl: software.amazon.awssdk.services.macie2.model.UserIdentityRoot
  ): zio.aws.macie2.model.UserIdentityRoot.ReadOnly = new Wrapper(impl)
}
